@@ -79,12 +79,12 @@ class Instrument:
 
     __slots__ = 'ins_code', 'l18', 'l30'
 
-    def __init__(self, id: Union[int, str]):
+    def __init__(self, id_: Union[int, str], /):
         try:
-            self.ins_code, self.l18, self.l30 = KNOWN_IDS[id]
+            self.ins_code, self.l18, self.l30 = KNOWN_IDS[id_]
         except KeyError:
-            if isinstance(id, int):
-                self.ins_code = id
+            if isinstance(id_, int):
+                self.ins_code = id_
                 self.l18 = self.l30 = None
                 return
             raise KeyError(
@@ -262,8 +262,6 @@ def get_market_watch_init(index=False) -> dict:
             'ins_code', 'isin', 'l18', 'l30', 'heven', 'pf', 'pc', 'pl', 'tno'
             , 'tvol', 'tval', 'pmin', 'pmax', 'py', 'eps', 'bvol', 'visitcount'
             , 'flow', 'cs', 'tmax', 'tmin', 'z', 'yval')
-        # unlike int64, Int64 is nullable
-        , dtype={'tmin': "Int64", 'tmax': "Int64"}
         , low_memory=False
         , index_col=['ins_code', 'isin', 'l18', 'l30'])
     price_df = read_csv(
